# -*- coding: utf-8 -*-
from xhpy.pylib import *
name = u"André"
result = <p>{name}</p>
